# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'EmailDomainDnsValidationRecordArgs',
]

@pulumi.input_type
class EmailDomainDnsValidationRecordArgs:
    def __init__(__self__, *,
                 expiration: Optional[pulumi.Input[str]] = None,
                 fqdn: Optional[pulumi.Input[str]] = None,
                 record_type: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] fqdn: DNS record name.
        :param pulumi.Input[str] record_type: Record type can be TXT or cname.
        :param pulumi.Input[str] value: DNS record value
               - `expiration ` - DNS TXT record expiration
        """
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if fqdn is not None:
            pulumi.set(__self__, "fqdn", fqdn)
        if record_type is not None:
            pulumi.set(__self__, "record_type", record_type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def expiration(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "expiration")

    @expiration.setter
    def expiration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expiration", value)

    @property
    @pulumi.getter
    def fqdn(self) -> Optional[pulumi.Input[str]]:
        """
        DNS record name.
        """
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fqdn", value)

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> Optional[pulumi.Input[str]]:
        """
        Record type can be TXT or cname.
        """
        return pulumi.get(self, "record_type")

    @record_type.setter
    def record_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "record_type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        DNS record value
        - `expiration ` - DNS TXT record expiration
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'EmailDomainDnsValidationRecord',
    'GetDomainDnsRecordResult',
]

@pulumi.output_type
class EmailDomainDnsValidationRecord(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "recordType":
            suggest = "record_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EmailDomainDnsValidationRecord. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EmailDomainDnsValidationRecord.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EmailDomainDnsValidationRecord.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expiration: Optional[str] = None,
                 fqdn: Optional[str] = None,
                 record_type: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str fqdn: DNS record name.
        :param str record_type: Record type can be TXT or cname.
        :param str value: DNS record value
               - `expiration ` - DNS TXT record expiration
        """
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if fqdn is not None:
            pulumi.set(__self__, "fqdn", fqdn)
        if record_type is not None:
            pulumi.set(__self__, "record_type", record_type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def expiration(self) -> Optional[str]:
        return pulumi.get(self, "expiration")

    @property
    @pulumi.getter
    def fqdn(self) -> Optional[str]:
        """
        DNS record name.
        """
        return pulumi.get(self, "fqdn")

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> Optional[str]:
        """
        Record type can be TXT or cname.
        """
        return pulumi.get(self, "record_type")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        DNS record value
        - `expiration ` - DNS TXT record expiration
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetDomainDnsRecordResult(dict):
    def __init__(__self__, *,
                 expiration: str,
                 fqdn: str,
                 record_type: str,
                 values: Sequence[str]):
        """
        :param str expiration: TXT record expiration.
        :param str fqdn: DNS record name.
        :param str record_type: Record type can be TXT or CNAME.
        :param Sequence[str] values: DNS verification value
        """
        pulumi.set(__self__, "expiration", expiration)
        pulumi.set(__self__, "fqdn", fqdn)
        pulumi.set(__self__, "record_type", record_type)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def expiration(self) -> str:
        """
        TXT record expiration.
        """
        return pulumi.get(self, "expiration")

    @property
    @pulumi.getter
    def fqdn(self) -> str:
        """
        DNS record name.
        """
        return pulumi.get(self, "fqdn")

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> str:
        """
        Record type can be TXT or CNAME.
        """
        return pulumi.get(self, "record_type")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        """
        DNS verification value
        """
        return pulumi.get(self, "values")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ThemeArgs', 'Theme']

@pulumi.input_type
class ThemeArgs:
    def __init__(__self__, *,
                 brand_id: pulumi.Input[str],
                 background_image: Optional[pulumi.Input[str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 favicon: Optional[pulumi.Input[str]] = None,
                 logo: Optional[pulumi.Input[str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 primary_color_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 theme_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Theme resource.
        :param pulumi.Input[str] brand_id: Brand ID
        :param pulumi.Input[str] background_image: (Optional) Local path to background image file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] email_template_touch_point_variant: (Required) Variant for email templates. Valid values: (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[str] end_user_dashboard_touch_point_variant: (Required) Variant for the Okta End-User Dashboard. Valid values: (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[str] error_page_touch_point_variant: (Required) Variant for the error page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] favicon: (Optional) Local path to favicon file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] logo: (Optional) Local path to logo file. Setting the value to the blank string `""` will delete the logo on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] primary_color_contrast_hex: (Optional) Primary color contrast hex code
        :param pulumi.Input[str] primary_color_hex: (Required) Primary color hex code
        :param pulumi.Input[str] secondary_color_contrast_hex: (Optional) Secondary color contrast hex code
        :param pulumi.Input[str] secondary_color_hex: (Required) Secondary color hex code
        :param pulumi.Input[str] sign_in_page_touch_point_variant: (Required) Variant for the Okta Sign-In Page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] theme_id: Theme ID, used for read (faux-create)
        """
        pulumi.set(__self__, "brand_id", brand_id)
        if background_image is not None:
            pulumi.set(__self__, "background_image", background_image)
        if email_template_touch_point_variant is not None:
            pulumi.set(__self__, "email_template_touch_point_variant", email_template_touch_point_variant)
        if end_user_dashboard_touch_point_variant is not None:
            pulumi.set(__self__, "end_user_dashboard_touch_point_variant", end_user_dashboard_touch_point_variant)
        if error_page_touch_point_variant is not None:
            pulumi.set(__self__, "error_page_touch_point_variant", error_page_touch_point_variant)
        if favicon is not None:
            pulumi.set(__self__, "favicon", favicon)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if primary_color_contrast_hex is not None:
            pulumi.set(__self__, "primary_color_contrast_hex", primary_color_contrast_hex)
        if primary_color_hex is not None:
            pulumi.set(__self__, "primary_color_hex", primary_color_hex)
        if secondary_color_contrast_hex is not None:
            pulumi.set(__self__, "secondary_color_contrast_hex", secondary_color_contrast_hex)
        if secondary_color_hex is not None:
            pulumi.set(__self__, "secondary_color_hex", secondary_color_hex)
        if sign_in_page_touch_point_variant is not None:
            pulumi.set(__self__, "sign_in_page_touch_point_variant", sign_in_page_touch_point_variant)
        if theme_id is not None:
            pulumi.set(__self__, "theme_id", theme_id)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Input[str]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "brand_id", value)

    @property
    @pulumi.getter(name="backgroundImage")
    def background_image(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Local path to background image file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "background_image")

    @background_image.setter
    def background_image(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "background_image", value)

    @property
    @pulumi.getter(name="emailTemplateTouchPointVariant")
    def email_template_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for email templates. Valid values: (`OKTA_DEFAULT`, `FULL_THEME`)
        """
        return pulumi.get(self, "email_template_touch_point_variant")

    @email_template_touch_point_variant.setter
    def email_template_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_template_touch_point_variant", value)

    @property
    @pulumi.getter(name="endUserDashboardTouchPointVariant")
    def end_user_dashboard_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for the Okta End-User Dashboard. Valid values: (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        """
        return pulumi.get(self, "end_user_dashboard_touch_point_variant")

    @end_user_dashboard_touch_point_variant.setter
    def end_user_dashboard_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_user_dashboard_touch_point_variant", value)

    @property
    @pulumi.getter(name="errorPageTouchPointVariant")
    def error_page_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for the error page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "error_page_touch_point_variant")

    @error_page_touch_point_variant.setter
    def error_page_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "error_page_touch_point_variant", value)

    @property
    @pulumi.getter
    def favicon(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Local path to favicon file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "favicon")

    @favicon.setter
    def favicon(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "favicon", value)

    @property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Local path to logo file. Setting the value to the blank string `""` will delete the logo on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logo", value)

    @property
    @pulumi.getter(name="primaryColorContrastHex")
    def primary_color_contrast_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Primary color contrast hex code
        """
        return pulumi.get(self, "primary_color_contrast_hex")

    @primary_color_contrast_hex.setter
    def primary_color_contrast_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "primary_color_contrast_hex", value)

    @property
    @pulumi.getter(name="primaryColorHex")
    def primary_color_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Primary color hex code
        """
        return pulumi.get(self, "primary_color_hex")

    @primary_color_hex.setter
    def primary_color_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "primary_color_hex", value)

    @property
    @pulumi.getter(name="secondaryColorContrastHex")
    def secondary_color_contrast_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Secondary color contrast hex code
        """
        return pulumi.get(self, "secondary_color_contrast_hex")

    @secondary_color_contrast_hex.setter
    def secondary_color_contrast_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_color_contrast_hex", value)

    @property
    @pulumi.getter(name="secondaryColorHex")
    def secondary_color_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Secondary color hex code
        """
        return pulumi.get(self, "secondary_color_hex")

    @secondary_color_hex.setter
    def secondary_color_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_color_hex", value)

    @property
    @pulumi.getter(name="signInPageTouchPointVariant")
    def sign_in_page_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for the Okta Sign-In Page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "sign_in_page_touch_point_variant")

    @sign_in_page_touch_point_variant.setter
    def sign_in_page_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sign_in_page_touch_point_variant", value)

    @property
    @pulumi.getter(name="themeId")
    def theme_id(self) -> Optional[pulumi.Input[str]]:
        """
        Theme ID, used for read (faux-create)
        """
        return pulumi.get(self, "theme_id")

    @theme_id.setter
    def theme_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "theme_id", value)


@pulumi.input_type
class _ThemeState:
    def __init__(__self__, *,
                 background_image: Optional[pulumi.Input[str]] = None,
                 background_image_url: Optional[pulumi.Input[str]] = None,
                 brand_id: Optional[pulumi.Input[str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 favicon: Optional[pulumi.Input[str]] = None,
                 favicon_url: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[str]] = None,
                 logo: Optional[pulumi.Input[str]] = None,
                 logo_url: Optional[pulumi.Input[str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 primary_color_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 theme_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Theme resources.
        :param pulumi.Input[str] background_image: (Optional) Local path to background image file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] background_image_url: (Read-Only) Background image URL
        :param pulumi.Input[str] brand_id: Brand ID
        :param pulumi.Input[str] email_template_touch_point_variant: (Required) Variant for email templates. Valid values: (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[str] end_user_dashboard_touch_point_variant: (Required) Variant for the Okta End-User Dashboard. Valid values: (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[str] error_page_touch_point_variant: (Required) Variant for the error page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] favicon: (Optional) Local path to favicon file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] favicon_url: (Read-Only) Favicon URL
        :param pulumi.Input[str] links: Link relations for this object - JSON HAL - (Read-Only) Discoverable resources related to the brand
        :param pulumi.Input[str] logo: (Optional) Local path to logo file. Setting the value to the blank string `""` will delete the logo on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] logo_url: (Read-Only) Logo URL
        :param pulumi.Input[str] primary_color_contrast_hex: (Optional) Primary color contrast hex code
        :param pulumi.Input[str] primary_color_hex: (Required) Primary color hex code
        :param pulumi.Input[str] secondary_color_contrast_hex: (Optional) Secondary color contrast hex code
        :param pulumi.Input[str] secondary_color_hex: (Required) Secondary color hex code
        :param pulumi.Input[str] sign_in_page_touch_point_variant: (Required) Variant for the Okta Sign-In Page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] theme_id: Theme ID, used for read (faux-create)
        """
        if background_image is not None:
            pulumi.set(__self__, "background_image", background_image)
        if background_image_url is not None:
            pulumi.set(__self__, "background_image_url", background_image_url)
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if email_template_touch_point_variant is not None:
            pulumi.set(__self__, "email_template_touch_point_variant", email_template_touch_point_variant)
        if end_user_dashboard_touch_point_variant is not None:
            pulumi.set(__self__, "end_user_dashboard_touch_point_variant", end_user_dashboard_touch_point_variant)
        if error_page_touch_point_variant is not None:
            pulumi.set(__self__, "error_page_touch_point_variant", error_page_touch_point_variant)
        if favicon is not None:
            pulumi.set(__self__, "favicon", favicon)
        if favicon_url is not None:
            pulumi.set(__self__, "favicon_url", favicon_url)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if logo_url is not None:
            pulumi.set(__self__, "logo_url", logo_url)
        if primary_color_contrast_hex is not None:
            pulumi.set(__self__, "primary_color_contrast_hex", primary_color_contrast_hex)
        if primary_color_hex is not None:
            pulumi.set(__self__, "primary_color_hex", primary_color_hex)
        if secondary_color_contrast_hex is not None:
            pulumi.set(__self__, "secondary_color_contrast_hex", secondary_color_contrast_hex)
        if secondary_color_hex is not None:
            pulumi.set(__self__, "secondary_color_hex", secondary_color_hex)
        if sign_in_page_touch_point_variant is not None:
            pulumi.set(__self__, "sign_in_page_touch_point_variant", sign_in_page_touch_point_variant)
        if theme_id is not None:
            pulumi.set(__self__, "theme_id", theme_id)

    @property
    @pulumi.getter(name="backgroundImage")
    def background_image(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Local path to background image file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "background_image")

    @background_image.setter
    def background_image(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "background_image", value)

    @property
    @pulumi.getter(name="backgroundImageUrl")
    def background_image_url(self) -> Optional[pulumi.Input[str]]:
        """
        (Read-Only) Background image URL
        """
        return pulumi.get(self, "background_image_url")

    @background_image_url.setter
    def background_image_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "background_image_url", value)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[str]]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "brand_id", value)

    @property
    @pulumi.getter(name="emailTemplateTouchPointVariant")
    def email_template_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for email templates. Valid values: (`OKTA_DEFAULT`, `FULL_THEME`)
        """
        return pulumi.get(self, "email_template_touch_point_variant")

    @email_template_touch_point_variant.setter
    def email_template_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_template_touch_point_variant", value)

    @property
    @pulumi.getter(name="endUserDashboardTouchPointVariant")
    def end_user_dashboard_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for the Okta End-User Dashboard. Valid values: (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        """
        return pulumi.get(self, "end_user_dashboard_touch_point_variant")

    @end_user_dashboard_touch_point_variant.setter
    def end_user_dashboard_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_user_dashboard_touch_point_variant", value)

    @property
    @pulumi.getter(name="errorPageTouchPointVariant")
    def error_page_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for the error page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "error_page_touch_point_variant")

    @error_page_touch_point_variant.setter
    def error_page_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "error_page_touch_point_variant", value)

    @property
    @pulumi.getter
    def favicon(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Local path to favicon file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "favicon")

    @favicon.setter
    def favicon(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "favicon", value)

    @property
    @pulumi.getter(name="faviconUrl")
    def favicon_url(self) -> Optional[pulumi.Input[str]]:
        """
        (Read-Only) Favicon URL
        """
        return pulumi.get(self, "favicon_url")

    @favicon_url.setter
    def favicon_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "favicon_url", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[str]]:
        """
        Link relations for this object - JSON HAL - (Read-Only) Discoverable resources related to the brand
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Local path to logo file. Setting the value to the blank string `""` will delete the logo on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logo", value)

    @property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> Optional[pulumi.Input[str]]:
        """
        (Read-Only) Logo URL
        """
        return pulumi.get(self, "logo_url")

    @logo_url.setter
    def logo_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logo_url", value)

    @property
    @pulumi.getter(name="primaryColorContrastHex")
    def primary_color_contrast_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Primary color contrast hex code
        """
        return pulumi.get(self, "primary_color_contrast_hex")

    @primary_color_contrast_hex.setter
    def primary_color_contrast_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "primary_color_contrast_hex", value)

    @property
    @pulumi.getter(name="primaryColorHex")
    def primary_color_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Primary color hex code
        """
        return pulumi.get(self, "primary_color_hex")

    @primary_color_hex.setter
    def primary_color_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "primary_color_hex", value)

    @property
    @pulumi.getter(name="secondaryColorContrastHex")
    def secondary_color_contrast_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Optional) Secondary color contrast hex code
        """
        return pulumi.get(self, "secondary_color_contrast_hex")

    @secondary_color_contrast_hex.setter
    def secondary_color_contrast_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_color_contrast_hex", value)

    @property
    @pulumi.getter(name="secondaryColorHex")
    def secondary_color_hex(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Secondary color hex code
        """
        return pulumi.get(self, "secondary_color_hex")

    @secondary_color_hex.setter
    def secondary_color_hex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_color_hex", value)

    @property
    @pulumi.getter(name="signInPageTouchPointVariant")
    def sign_in_page_touch_point_variant(self) -> Optional[pulumi.Input[str]]:
        """
        (Required) Variant for the Okta Sign-In Page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "sign_in_page_touch_point_variant")

    @sign_in_page_touch_point_variant.setter
    def sign_in_page_touch_point_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sign_in_page_touch_point_variant", value)

    @property
    @pulumi.getter(name="themeId")
    def theme_id(self) -> Optional[pulumi.Input[str]]:
        """
        Theme ID, used for read (faux-create)
        """
        return pulumi.get(self, "theme_id")

    @theme_id.setter
    def theme_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "theme_id", value)


class Theme(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 background_image: Optional[pulumi.Input[str]] = None,
                 brand_id: Optional[pulumi.Input[str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 favicon: Optional[pulumi.Input[str]] = None,
                 logo: Optional[pulumi.Input[str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 primary_color_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 theme_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        An Okta Brand can be imported via the ID.

        ```sh
         $ pulumi import okta:index/theme:Theme example &#60;brand id&#62;/&#60;theme id&#62;
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] background_image: (Optional) Local path to background image file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] brand_id: Brand ID
        :param pulumi.Input[str] email_template_touch_point_variant: (Required) Variant for email templates. Valid values: (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[str] end_user_dashboard_touch_point_variant: (Required) Variant for the Okta End-User Dashboard. Valid values: (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[str] error_page_touch_point_variant: (Required) Variant for the error page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] favicon: (Optional) Local path to favicon file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] logo: (Optional) Local path to logo file. Setting the value to the blank string `""` will delete the logo on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] primary_color_contrast_hex: (Optional) Primary color contrast hex code
        :param pulumi.Input[str] primary_color_hex: (Required) Primary color hex code
        :param pulumi.Input[str] secondary_color_contrast_hex: (Optional) Secondary color contrast hex code
        :param pulumi.Input[str] secondary_color_hex: (Required) Secondary color hex code
        :param pulumi.Input[str] sign_in_page_touch_point_variant: (Required) Variant for the Okta Sign-In Page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] theme_id: Theme ID, used for read (faux-create)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ThemeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        An Okta Brand can be imported via the ID.

        ```sh
         $ pulumi import okta:index/theme:Theme example &#60;brand id&#62;/&#60;theme id&#62;
        ```

        :param str resource_name: The name of the resource.
        :param ThemeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ThemeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 background_image: Optional[pulumi.Input[str]] = None,
                 brand_id: Optional[pulumi.Input[str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 favicon: Optional[pulumi.Input[str]] = None,
                 logo: Optional[pulumi.Input[str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 primary_color_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
                 theme_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ThemeArgs.__new__(ThemeArgs)

            __props__.__dict__["background_image"] = background_image
            if brand_id is None and not opts.urn:
                raise TypeError("Missing required property 'brand_id'")
            __props__.__dict__["brand_id"] = brand_id
            __props__.__dict__["email_template_touch_point_variant"] = email_template_touch_point_variant
            __props__.__dict__["end_user_dashboard_touch_point_variant"] = end_user_dashboard_touch_point_variant
            __props__.__dict__["error_page_touch_point_variant"] = error_page_touch_point_variant
            __props__.__dict__["favicon"] = favicon
            __props__.__dict__["logo"] = logo
            __props__.__dict__["primary_color_contrast_hex"] = primary_color_contrast_hex
            __props__.__dict__["primary_color_hex"] = primary_color_hex
            __props__.__dict__["secondary_color_contrast_hex"] = secondary_color_contrast_hex
            __props__.__dict__["secondary_color_hex"] = secondary_color_hex
            __props__.__dict__["sign_in_page_touch_point_variant"] = sign_in_page_touch_point_variant
            __props__.__dict__["theme_id"] = theme_id
            __props__.__dict__["background_image_url"] = None
            __props__.__dict__["favicon_url"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["logo_url"] = None
        super(Theme, __self__).__init__(
            'okta:index/theme:Theme',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            background_image: Optional[pulumi.Input[str]] = None,
            background_image_url: Optional[pulumi.Input[str]] = None,
            brand_id: Optional[pulumi.Input[str]] = None,
            email_template_touch_point_variant: Optional[pulumi.Input[str]] = None,
            end_user_dashboard_touch_point_variant: Optional[pulumi.Input[str]] = None,
            error_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
            favicon: Optional[pulumi.Input[str]] = None,
            favicon_url: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[str]] = None,
            logo: Optional[pulumi.Input[str]] = None,
            logo_url: Optional[pulumi.Input[str]] = None,
            primary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
            primary_color_hex: Optional[pulumi.Input[str]] = None,
            secondary_color_contrast_hex: Optional[pulumi.Input[str]] = None,
            secondary_color_hex: Optional[pulumi.Input[str]] = None,
            sign_in_page_touch_point_variant: Optional[pulumi.Input[str]] = None,
            theme_id: Optional[pulumi.Input[str]] = None) -> 'Theme':
        """
        Get an existing Theme resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] background_image: (Optional) Local path to background image file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] background_image_url: (Read-Only) Background image URL
        :param pulumi.Input[str] brand_id: Brand ID
        :param pulumi.Input[str] email_template_touch_point_variant: (Required) Variant for email templates. Valid values: (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[str] end_user_dashboard_touch_point_variant: (Required) Variant for the Okta End-User Dashboard. Valid values: (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[str] error_page_touch_point_variant: (Required) Variant for the error page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] favicon: (Optional) Local path to favicon file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] favicon_url: (Read-Only) Favicon URL
        :param pulumi.Input[str] links: Link relations for this object - JSON HAL - (Read-Only) Discoverable resources related to the brand
        :param pulumi.Input[str] logo: (Optional) Local path to logo file. Setting the value to the blank string `""` will delete the logo on the theme at Okta but will not delete the local file.
        :param pulumi.Input[str] logo_url: (Read-Only) Logo URL
        :param pulumi.Input[str] primary_color_contrast_hex: (Optional) Primary color contrast hex code
        :param pulumi.Input[str] primary_color_hex: (Required) Primary color hex code
        :param pulumi.Input[str] secondary_color_contrast_hex: (Optional) Secondary color contrast hex code
        :param pulumi.Input[str] secondary_color_hex: (Required) Secondary color hex code
        :param pulumi.Input[str] sign_in_page_touch_point_variant: (Required) Variant for the Okta Sign-In Page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[str] theme_id: Theme ID, used for read (faux-create)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ThemeState.__new__(_ThemeState)

        __props__.__dict__["background_image"] = background_image
        __props__.__dict__["background_image_url"] = background_image_url
        __props__.__dict__["brand_id"] = brand_id
        __props__.__dict__["email_template_touch_point_variant"] = email_template_touch_point_variant
        __props__.__dict__["end_user_dashboard_touch_point_variant"] = end_user_dashboard_touch_point_variant
        __props__.__dict__["error_page_touch_point_variant"] = error_page_touch_point_variant
        __props__.__dict__["favicon"] = favicon
        __props__.__dict__["favicon_url"] = favicon_url
        __props__.__dict__["links"] = links
        __props__.__dict__["logo"] = logo
        __props__.__dict__["logo_url"] = logo_url
        __props__.__dict__["primary_color_contrast_hex"] = primary_color_contrast_hex
        __props__.__dict__["primary_color_hex"] = primary_color_hex
        __props__.__dict__["secondary_color_contrast_hex"] = secondary_color_contrast_hex
        __props__.__dict__["secondary_color_hex"] = secondary_color_hex
        __props__.__dict__["sign_in_page_touch_point_variant"] = sign_in_page_touch_point_variant
        __props__.__dict__["theme_id"] = theme_id
        return Theme(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backgroundImage")
    def background_image(self) -> pulumi.Output[Optional[str]]:
        """
        (Optional) Local path to background image file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "background_image")

    @property
    @pulumi.getter(name="backgroundImageUrl")
    def background_image_url(self) -> pulumi.Output[str]:
        """
        (Read-Only) Background image URL
        """
        return pulumi.get(self, "background_image_url")

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Output[str]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @property
    @pulumi.getter(name="emailTemplateTouchPointVariant")
    def email_template_touch_point_variant(self) -> pulumi.Output[Optional[str]]:
        """
        (Required) Variant for email templates. Valid values: (`OKTA_DEFAULT`, `FULL_THEME`)
        """
        return pulumi.get(self, "email_template_touch_point_variant")

    @property
    @pulumi.getter(name="endUserDashboardTouchPointVariant")
    def end_user_dashboard_touch_point_variant(self) -> pulumi.Output[Optional[str]]:
        """
        (Required) Variant for the Okta End-User Dashboard. Valid values: (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        """
        return pulumi.get(self, "end_user_dashboard_touch_point_variant")

    @property
    @pulumi.getter(name="errorPageTouchPointVariant")
    def error_page_touch_point_variant(self) -> pulumi.Output[Optional[str]]:
        """
        (Required) Variant for the error page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "error_page_touch_point_variant")

    @property
    @pulumi.getter
    def favicon(self) -> pulumi.Output[Optional[str]]:
        """
        (Optional) Local path to favicon file. Setting the value to the blank string `""` will delete the favicon on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "favicon")

    @property
    @pulumi.getter(name="faviconUrl")
    def favicon_url(self) -> pulumi.Output[str]:
        """
        (Read-Only) Favicon URL
        """
        return pulumi.get(self, "favicon_url")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[str]:
        """
        Link relations for this object - JSON HAL - (Read-Only) Discoverable resources related to the brand
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def logo(self) -> pulumi.Output[Optional[str]]:
        """
        (Optional) Local path to logo file. Setting the value to the blank string `""` will delete the logo on the theme at Okta but will not delete the local file.
        """
        return pulumi.get(self, "logo")

    @property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> pulumi.Output[str]:
        """
        (Read-Only) Logo URL
        """
        return pulumi.get(self, "logo_url")

    @property
    @pulumi.getter(name="primaryColorContrastHex")
    def primary_color_contrast_hex(self) -> pulumi.Output[Optional[str]]:
        """
        (Optional) Primary color contrast hex code
        """
        return pulumi.get(self, "primary_color_contrast_hex")

    @property
    @pulumi.getter(name="primaryColorHex")
    def primary_color_hex(self) -> pulumi.Output[Optional[str]]:
        """
        (Required) Primary color hex code
        """
        return pulumi.get(self, "primary_color_hex")

    @property
    @pulumi.getter(name="secondaryColorContrastHex")
    def secondary_color_contrast_hex(self) -> pulumi.Output[Optional[str]]:
        """
        (Optional) Secondary color contrast hex code
        """
        return pulumi.get(self, "secondary_color_contrast_hex")

    @property
    @pulumi.getter(name="secondaryColorHex")
    def secondary_color_hex(self) -> pulumi.Output[Optional[str]]:
        """
        (Required) Secondary color hex code
        """
        return pulumi.get(self, "secondary_color_hex")

    @property
    @pulumi.getter(name="signInPageTouchPointVariant")
    def sign_in_page_touch_point_variant(self) -> pulumi.Output[Optional[str]]:
        """
        (Required) Variant for the Okta Sign-In Page. Valid values: (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "sign_in_page_touch_point_variant")

    @property
    @pulumi.getter(name="themeId")
    def theme_id(self) -> pulumi.Output[Optional[str]]:
        """
        Theme ID, used for read (faux-create)
        """
        return pulumi.get(self, "theme_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppGroupAssignmentsArgs', 'AppGroupAssignments']

@pulumi.input_type
class AppGroupAssignmentsArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[str],
                 groups: pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]):
        """
        The set of arguments for constructing a AppGroupAssignments resource.
        :param pulumi.Input[str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]] groups: A group to assign the app to.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "groups", groups)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[str]:
        """
        The ID of the application to assign a group to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter
    def groups(self) -> pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]:
        """
        A group to assign the app to.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]):
        pulumi.set(self, "groups", value)


@pulumi.input_type
class _AppGroupAssignmentsState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[str]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]] = None):
        """
        Input properties used for looking up and filtering AppGroupAssignments resources.
        :param pulumi.Input[str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]] groups: A group to assign the app to.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the application to assign a group to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]]:
        """
        A group to assign the app to.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]]):
        pulumi.set(self, "groups", value)


class AppGroupAssignments(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AppGroupAssignmentsGroupArgs']]]]] = None,
                 __props__=None):
        """
        Assigns groups to an application.

        This resource allows you to create multiple App Group assignments.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        example = okta.AppGroupAssignments("example",
            app_id="<app id>",
            groups=[
                okta.AppGroupAssignmentsGroupArgs(
                    id="<group id>",
                    priority=1,
                ),
                okta.AppGroupAssignmentsGroupArgs(
                    id="<another group id>",
                    priority=2,
                    profile=json.dumps({
                        "application profile field": "application profile value",
                    }),
                ),
            ])
        ```

        !> **NOTE** It would seem that setting/updating base/custom group schema values
        was the original purpose for setting a `profile` JSON value during the [Assign
        group to
        application](https://developer.okta.com/docs/reference/api/apps/#assign-group-to-application)
        API call that will take place when the `priority` value is changed. We couldn't
        verify this works when writing a new integration test against this old feature
        and were receiving an API 400 error. This feature may work for older orgs, or
        classic orgs, but we can not guarantee for all orgs.

        !> **NOTE** When using this resource in conjunction with other application
        resources (e.g. `app.OAuth`) it is advisable to add the following
        `lifecycle` argument to the associated `app_*` resources to prevent the groups
        being unassigned on subsequent runs:

        ```python
        import pulumi
        import pulumi_okta as okta

        app = okta.app.OAuth("app")
        ```

        > **IMPORTANT:** When using `AppGroupAssignments` it is expected to manage ALL group assignments for the target application.

        ## Import

        An application's group assignments can be imported via `app_id`.

        ```sh
         $ pulumi import okta:index/appGroupAssignments:AppGroupAssignments example &#60;app_id&#62;
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AppGroupAssignmentsGroupArgs']]]] groups: A group to assign the app to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppGroupAssignmentsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Assigns groups to an application.

        This resource allows you to create multiple App Group assignments.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        example = okta.AppGroupAssignments("example",
            app_id="<app id>",
            groups=[
                okta.AppGroupAssignmentsGroupArgs(
                    id="<group id>",
                    priority=1,
                ),
                okta.AppGroupAssignmentsGroupArgs(
                    id="<another group id>",
                    priority=2,
                    profile=json.dumps({
                        "application profile field": "application profile value",
                    }),
                ),
            ])
        ```

        !> **NOTE** It would seem that setting/updating base/custom group schema values
        was the original purpose for setting a `profile` JSON value during the [Assign
        group to
        application](https://developer.okta.com/docs/reference/api/apps/#assign-group-to-application)
        API call that will take place when the `priority` value is changed. We couldn't
        verify this works when writing a new integration test against this old feature
        and were receiving an API 400 error. This feature may work for older orgs, or
        classic orgs, but we can not guarantee for all orgs.

        !> **NOTE** When using this resource in conjunction with other application
        resources (e.g. `app.OAuth`) it is advisable to add the following
        `lifecycle` argument to the associated `app_*` resources to prevent the groups
        being unassigned on subsequent runs:

        ```python
        import pulumi
        import pulumi_okta as okta

        app = okta.app.OAuth("app")
        ```

        > **IMPORTANT:** When using `AppGroupAssignments` it is expected to manage ALL group assignments for the target application.

        ## Import

        An application's group assignments can be imported via `app_id`.

        ```sh
         $ pulumi import okta:index/appGroupAssignments:AppGroupAssignments example &#60;app_id&#62;
        ```

        :param str resource_name: The name of the resource.
        :param AppGroupAssignmentsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppGroupAssignmentsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AppGroupAssignmentsGroupArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppGroupAssignmentsArgs.__new__(AppGroupAssignmentsArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if groups is None and not opts.urn:
                raise TypeError("Missing required property 'groups'")
            __props__.__dict__["groups"] = groups
        super(AppGroupAssignments, __self__).__init__(
            'okta:index/appGroupAssignments:AppGroupAssignments',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[str]] = None,
            groups: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AppGroupAssignmentsGroupArgs']]]]] = None) -> 'AppGroupAssignments':
        """
        Get an existing AppGroupAssignments resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AppGroupAssignmentsGroupArgs']]]] groups: A group to assign the app to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppGroupAssignmentsState.__new__(_AppGroupAssignmentsState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["groups"] = groups
        return AppGroupAssignments(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[str]:
        """
        The ID of the application to assign a group to.
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter
    def groups(self) -> pulumi.Output[Sequence['outputs.AppGroupAssignmentsGroup']]:
        """
        A group to assign the app to.
        """
        return pulumi.get(self, "groups")

